Amire80 has uploaded a new change for review.

  https://gerrit.wikimedia.org/r/98769


Change subject: Add GENDER support to flow-topic-comments
......................................................................

Add GENDER support to flow-topic-comments

Change-Id: Ieaded7d1df5d954932c377d4be321aeef382c391
---
M Flow.i18n.php
M templates/topic.html.php
2 files changed, 4 insertions(+), 3 deletions(-)


  git pull ssh://gerrit.wikimedia.org:29418/mediawiki/extensions/Flow 
refs/changes/69/98769/1

diff --git a/templates/topic.html.php b/templates/topic.html.php
index 9c03508..b7862a6 100644
--- a/templates/topic.html.php
+++ b/templates/topic.html.php
@@ -181,7 +181,7 @@
                                                // get total number of posts in 
topic
                                                // @todo: the number of 
comments should not be a part of the link
                                                $comments = 
$root->getRecursiveResult( $indexDescendantCount );
-                                               echo wfMessage( 
'flow-topic-comments', $comments )->text();
+                                               echo wfMessage( 
'flow-topic-comments', $comments, $user->getName() )->text();
                                        ?>
                                </a>
                        </li>

diff --git a/Flow.i18n.php b/Flow.i18n.php
index f2480e5..88dfa40 100644
--- a/Flow.i18n.php
+++ b/Flow.i18n.php
@@ -134,7 +134,7 @@
        'flow-history-pages-topic' => 'Appears on [$1 "$2" board]',
        'flow-history-pages-post' => 'Appears on [$1 $2]',
        'flow-topic-participants' => '{{PLURAL:$1|$3 started this 
topic|{{GENDER:$3|$3}}, {{GENDER:$4|$4}}, {{GENDER:$5|$5}} and $2 
{{PLURAL:$2|other|others}}|0=No participation yet|2={{GENDER:$3|$3}} and 
{{GENDER:$4|$4}}|3={{GENDER:$3|$3}}, {{GENDER:$4|$4}} and {{GENDER:$5|$5}}}}',
-       'flow-topic-comments' => '{{PLURAL:$1|Comment ($1)|Comments ($1)|0=Be 
the first to comment!}}',
+       'flow-topic-comments' => '{{PLURAL:$1|{{GENDER:$2|Comment}} 
($1)|Comments ($1)|0={{GENDER:$2|Be the first}} to comment!}}',
 
        'flow-comment-restored' => 'Restored comment',
        'flow-comment-deleted' => 'Deleted comment',
@@ -603,7 +603,8 @@
        'flow-topic-comments' => 'Message to display the amount of comments in 
this topic.
 
 Parameters:
 * $1 - The number of comments on this topic, can be used for PLURAL',
        'flow-comment-restored' => 'Used as revision comment when the post has 
been restored.
 
@@ -603,7 +603,8 @@
 
 Parameters:
-* $1 - The number of comments on this topic, can be used for PLURAL',
+* $1 - The number of comments on this topic, can be used for PLURAL
+* $2 - The name of the current user, for GENDER',
        'flow-comment-restored' => 'Used as revision comment when the post has 
been restored.
 See also:
-- 
To view, visit https://gerrit.wikimedia.org/r/98769
To unsubscribe, visit https://gerrit.wikimedia.org/r/settings

Gerrit-MessageType: newchange
Gerrit-Change-Id: Ieaded7d1df5d954932c377d4be321aeef382c391
Gerrit-PatchSet: 1
Gerrit-Project: mediawiki/extensions/Flow
Gerrit-Branch: master
Gerrit-Owner: Amire80 <amir.ahar...@mail.huji.ac.il>

_______________________________________________
MediaWiki-commits mailing list
MediaWiki-commits@lists.wikimedia.org
https://lists.wikimedia.org/mailman/listinfo/mediawiki-commits

Reply via email to